<?php

namespace Drupal\Tests\deprecation_status\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Smoke tests for deprecation status.
 *
 * @group deprecation_status
 */
class DeprecationStatusSmokeTest extends BrowserTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = ['deprecation_status'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests access without permission.
   */
  public function testAccessUnprivileged() {
    // Assuming visitors at least have access content permission.
    $this->drupalLogin($this->drupalCreateUser(['access content']));

    $this->drupalGet(Url::fromRoute('deprecation_status.projects_form'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Filter projects');
    $this->assertText('Covered by rector');
    $this->assertText('pathauto');

    $this->drupalGet(Url::fromRoute('deprecation_status.projects_form10'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Filter projects');
    $this->assertText('Covered by rector');
    $this->assertText('pathauto');

    $this->drupalGet(Url::fromRoute('deprecation_status.errors_form'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Filter errors');
    $this->assertText('Covered by rector');

    $this->drupalGet(Url::fromRoute('deprecation_status.errors_form10'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Filter errors');
    $this->assertText('Covered by rector');

    $this->drupalGet(Url::fromRoute('deprecation_status.error', ['error_index' => 1]));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Deprecation error details');

    $this->drupalGet(Url::fromRoute('deprecation_status.error10', ['error_index' => 1]));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Deprecation error details');

    $this->drupalGet(Url::fromRoute('deprecation_status.graphs'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Percentage of contributed projects by status in usage groups');
    $this->assertText('All drupal.org contributed projects by status over time');

    $this->drupalGet(Url::fromRoute('deprecation_status.graphs10'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Tracking based on @deprecated and E_USER_DEPRECATED mentions in Drupal 9 core.');

    $this->drupalGet(Url::fromRoute('deprecation_status.update'));
    $this->assertSession()->statusCodeEquals(403);
  }

  /**
   * Tests access with user that has the correct permission.
   */
  public function testAccessPrivileged() {
    $this->drupalLogin($this->drupalCreateUser(['access administration pages']));
    $this->drupalGet(Url::fromRoute('deprecation_status.update'));
    $this->assertSession()->statusCodeEquals(200);
    $this->assertText('Shipped dataset');
    $this->assertText('Current live dataset');
    $this->assertText('Online dataset');
  }

}
